Crate kcr_expansion_gatekeeper_sh

Crate kcr_expansion_gatekeeper_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the expansion.gatekeeper.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

expansion.gatekeeper.sh/v1alpha1

  • ExpansionTemplate

expansion.gatekeeper.sh/v1beta1

  • ExpansionTemplate

Modules

v1alpha1
v1beta1